@@ -3,7 +3,6 @@ Orange Canvas Main Window
 
 """
 import os
-import pkgutil
 import sys
 import logging
 import operator
@@ -29,7 +28,7 @@ from AnyQt.QtGui import (
     QWhatsThisClickedEvent, QShowEvent, QCloseEvent
 )
 from AnyQt.QtCore import (
-    Qt, QObject, QEvent, QSize, QUrl, QFile, QByteArray, QFileInfo,
+    Qt, QObject, QEvent, QSize, QUrl, QByteArray, QFileInfo,
     QSettings, QStandardPaths, QAbstractItemModel, QMimeData, QT_VERSION)
 
 try:
@@ -65,11 +64,13 @@ from .aboutdialog import AboutDialog
 from .schemeinfo import SchemeInfoDialog
 from .outputview import OutputView, TextStream
 from .settings import UserSettingsDialog, category_state
+from .utils.addons import normalize_name, is_requirement_available
 from ..document.schemeedit import SchemeEditWidget
 from ..document.quickmenu import QuickMenu
 from ..document.commands import UndoCommand
 from ..document import interactions
 from ..gui.itemmodels import FilterProxyModel
+from ..gui.windowlistmanager import WindowListManager
 from ..registry import WidgetRegistry, WidgetDescription, CategoryDescription
 from ..registry.qt import QtWidgetRegistry
 from ..utils.settings import QSettings_readArray, QSettings_writeArray
@@ -167,7 +168,12 @@ class CanvasMainWindow(QMainWindow):
         self.setup_actions()
         self.setup_ui()
         self.setup_menu()
-
+        windowmanager = WindowListManager.instance()
+        windowmanager.addWindow(self)
+        self.window_menu.addSeparator()
+        self.window_menu.addActions(windowmanager.actions())
+        windowmanager.windowAdded.connect(self.__window_added)
+        windowmanager.windowRemoved.connect(self.__window_removed)
         self.restore()
 
     def setup_ui(self):
@@ -550,18 +556,19 @@ class CanvasMainWindow(QMainWindow):
             triggered=lambda checked: self.output_dock.setVisible(
                 checked),
         )
-        if sys.platform == "darwin":
-            # Actions for native Mac OSX look and feel.
-            self.minimize_action = QAction(
-                self.tr("Minimize"), self,
-                triggered=self.showMinimized,
-                shortcut=QKeySequence("Ctrl+M")
-            )
-            self.zoom_action = QAction(
-                self.tr("Zoom"), self,
-                objectName="application-zoom",
-                triggered=self.toggleMaximized,
-            )
+        # Actions for native Mac OSX look and feel.
+        self.minimize_action = QAction(
+            self.tr("Minimize"), self,
+            triggered=self.showMinimized,
+            shortcut=QKeySequence("Ctrl+M"),
+            visible=sys.platform == "darwin",
+        )
+        self.zoom_action = QAction(
+            self.tr("Zoom"), self,
+            objectName="application-zoom",
+            triggered=self.toggleMaximized,
+            visible=sys.platform == "darwin",
+        )
         self.freeze_action = QAction(
             self.tr("Freeze"), self,
             shortcut=QKeySequence("Shift+F"),
@@ -706,13 +713,6 @@ class CanvasMainWindow(QMainWindow):
         sep.setObjectName("view-zoom-actions-separator")
 
         self.view_menu.addAction(self.toogle_margins_action)
-        raise_widgets_action = self.scheme_widget.findChild(
-            QAction, "bring-widgets-to-front-action"
-        )
-        if raise_widgets_action is not None:
-            self.view_menu.addAction(raise_widgets_action)
-
-        self.view_menu.addAction(self.float_widgets_on_top_action)
         menu_bar.addMenu(self.view_menu)
 
         # Options menu
@@ -725,15 +725,21 @@ class CanvasMainWindow(QMainWindow):
         # Widget menu
         menu_bar.addMenu(self.widget_menu)
 
-        if sys.platform == "darwin":
-            # Mac OS X native look and feel.
-            self.window_menu = QMenu(
-                self.tr("Window"), menu_bar, objectName="window-menu"
-            )
-            self.window_menu.addAction(self.minimize_action)
-            self.window_menu.addAction(self.zoom_action)
-            menu_bar.addMenu(self.window_menu)
+        # Mac OS X native look and feel.
+        self.window_menu = QMenu(
+            self.tr("Window"), menu_bar, objectName="window-menu"
+        )
+        self.window_menu.addAction(self.minimize_action)
+        self.window_menu.addAction(self.zoom_action)
+        self.window_menu.addSeparator()
+        raise_widgets_action = self.scheme_widget.findChild(
+            QAction, "bring-widgets-to-front-action"
+        )
+        if raise_widgets_action is not None:
+            self.window_menu.addAction(raise_widgets_action)
 
+        self.window_menu.addAction(self.float_widgets_on_top_action)
+        menu_bar.addMenu(self.window_menu)
         menu_bar.addMenu(self.options_menu)
 
         # Help menu.
@@ -789,6 +795,12 @@ class CanvasMainWindow(QMainWindow):
 
         self.__update_from_settings()
 
+    def __window_added(self, _, action: QAction) -> None:
+        self.window_menu.addAction(action)
+
+    def __window_removed(self, _, action: QAction) -> None:
+        self.window_menu.removeAction(action)
+
     def __update_window_title(self):
         path = self.current_document().path()
         if path:
@@ -799,8 +811,21 @@ class CanvasMainWindow(QMainWindow):
             self.setWindowTitle(self.tr("Untitled [*]"))
 
     def setWindowFilePath(self, filePath):  # type: (str) -> None
+        def icon_for_path(path: str) -> 'QIcon':
+            iconprovider = QFileIconProvider()
+            finfo = QFileInfo(path)
+            if finfo.exists():
+                return iconprovider.icon(finfo)
+            else:
+                return iconprovider.icon(QFileIconProvider.File)
+
         if sys.platform == "darwin":
             super().setWindowFilePath(filePath)
+            # If QApplication.windowIcon() is not null then it is used instead
+            # of the file type specific one. This is wrong so we set it
+            # explicitly.
+            if not QApplication.windowIcon().isNull() and filePath:
+                self.setWindowIcon(icon_for_path(filePath))
         else:
             # use non-empty path to 'force' Qt to add '[*]' modified marker
             # in the displayed title.
@@ -1268,8 +1293,7 @@ class CanvasMainWindow(QMainWindow):
 
     def check_requires(self, fileobj: IO) -> bool:
         requires = scheme_requires(fileobj, self.widget_registry)
-        requires = [req for req in requires
-                    if not addons.is_requirement_available(req)]
+        requires = [req for req in requires if not is_requirement_available(req)]
         if requires:
             details_ = [
                 "<h4>Required packages:</h4><ul>",
@@ -1331,7 +1355,7 @@ class CanvasMainWindow(QMainWindow):
         dlg.setConfig(config.default)
         req = addons.Requirement
         names = [req.parse(r).project_name for r in requires]
-        normalized_names = {addons.normalize_name(r) for r in names}
+        normalized_names = {normalize_name(r) for r in names}
 
         def set_state(*args):
             # select all query items for installation
@@ -1618,14 +1642,20 @@ class CanvasMainWindow(QMainWindow):
         document = self.current_document()
         path = document.path()
 
+        def remove(filename: str) -> None:
+            try:
+                os.remove(filename)
+            except FileNotFoundError:
+                pass
+            except OSError as e:
+                log.warning("Could not delete swp file: %s", e)
+
         if path or self in canvas_scratch_name_memo:
-            swpname = swp_name(self)
-            if os.path.exists(swpname):
-                os.remove(swpname)
+            remove(swp_name(self))
         else:
             swpnames = glob_scratch_swps()
             for swpname in swpnames:
-                os.remove(swpname)
+                remove(swpname)
 
     def ask_load_swp_if_exists(self):
         """
@@ -2046,7 +2076,7 @@ class CanvasMainWindow(QMainWindow):
         """Open the add-on manager dialog.
         """
         name = QApplication.applicationName() or "Orange"
-        from .addons import have_install_permissions
+        from orangecanvas.application.utils.addons import have_install_permissions
         if not have_install_permissions():
             QMessageBox(QMessageBox.Warning,
                         "Add-ons: insufficient permissions",
@@ -2252,6 +2282,8 @@ class CanvasMainWindow(QMainWindow):
         self.help_dock.close()
         self.output_dock.close()
         super().closeEvent(event)
+        windowlist = WindowListManager.instance()
+        windowlist.removeWindow(self)
 
     __did_restore = False
 
@@ -2361,20 +2393,15 @@ class CanvasMainWindow(QMainWindow):
             self.help_dock.show()
             self.help_dock.raise_()
 
-    # Mac OS X
-    if sys.platform == "darwin":
-        def toggleMaximized(self):
-            # type: () -> None
-            """Toggle normal/maximized window state.
-            """
-            if self.isMinimized():
-                # Do nothing if window is minimized
-                return
-
-            if self.isMaximized():
-                self.showNormal()
-            else:
-                self.showMaximized()
+    def toggleMaximized(self) -> None:
+        """Toggle normal/maximized window state.
+        """
+        if self.isMinimized():  # Do nothing if window is minimized
+            return
+        if self.isMaximized():
+            self.showNormal()
+        else:
+            self.showMaximized()
 
     def sizeHint(self):
         # type: () -> QSize
