@@ -133,10 +133,14 @@ class SchemeNode(QObject):
         Return the input channel matching `name`. Raise a `ValueError`
         if not found.
         """
+        for channel in self.input_channels():
+            if channel.id == name:
+                return channel
+        # Fallback to channel names for backward compatibility
         for channel in self.input_channels():
             if channel.name == name:
                 return channel
-        raise ValueError("%r is not a valid input channel name for %r." % \
+        raise ValueError("%r is not a valid input channel for %r." % \
                          (name, self.description.name))
 
     def output_channel(self, name):
@@ -145,10 +149,14 @@ class SchemeNode(QObject):
         Return the output channel matching `name`. Raise an `ValueError`
         if not found.
         """
+        for channel in self.output_channels():
+            if channel.id == name:
+                return channel
+        # Fallback to channel names for backward compatibility
         for channel in self.output_channels():
             if channel.name == name:
                 return channel
-        raise ValueError("%r is not a valid output channel name for %r." % \
+        raise ValueError("%r is not a valid output channel for %r." % \
                          (name, self.description.name))
 
     #: The title of the node has changed
